pub struct CaptureEvent(pub u32);Expand description
Opaque identifier for an event used to thread cross-stream dependencies.
Mirrors a cudaEvent_t that is recorded on one stream and waited on by
another to reconstruct fork / join parallelism in a captured graph.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for CaptureEvent
impl Clone for CaptureEvent
Sourcefn clone(&self) -> CaptureEvent
fn clone(&self) -> CaptureEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CaptureEvent
Sourceimpl Debug for CaptureEvent
impl Debug for CaptureEvent
Sourceimpl Display for CaptureEvent
impl Display for CaptureEvent
impl Eq for CaptureEvent
Sourceimpl Hash for CaptureEvent
impl Hash for CaptureEvent
Sourceimpl Ord for CaptureEvent
impl Ord for CaptureEvent
Sourcefn cmp(&self, other: &CaptureEvent) -> Ordering
fn cmp(&self, other: &CaptureEvent) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CaptureEvent
impl PartialEq for CaptureEvent
Sourceimpl PartialOrd for CaptureEvent
impl PartialOrd for CaptureEvent
impl StructuralPartialEq for CaptureEvent