pub fn capture(plan: &ExecutionPlan) -> GraphResult<Graph>Expand description
Captures an ExecutionPlan into a driver::graph::Graph.
Returns the resulting graph, ready to be instantiated via
Graph::instantiate.
Errors
Returns a GraphError if any step cannot be added to the graph.